# -*- coding: utf-8 -*-
from __future__ import with_statement

from setuptools import setup


def get_version(fname="mccabe.py"):
    with open(fname) as f:
        for line in f:
            if line.startswith("__version__"):
                return eval(line.split("=")[-1])


def get_long_description():
    descr = []
    for fname in ("README.rst",):
        with open(fname) as f:
            descr.append(f.read())
    return "\n\n".join(descr)


setup(
    name="mccabe",
    version=get_version(),
    description="McCabe checker, plugin for flake8",
    long_description=get_long_description(),
    keywords="flake8 mccabe",
    author="Tarek Ziade",
    author_email="tarek@ziade.org",
    maintainer="Ian Stapleton Cordasco",
    maintainer_email="graffatcolmingov@gmail.com",
    url="https://github.com/pycqa/mccabe",
    license="Expat license",
    py_modules=["mccabe"],
    zip_safe=False,
    entry_points={
        "flake8.extension": [
            "C90 = mccabe:McCabeChecker",
        ],
    },
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Software Development :: Quality Assurance",
    ],
    python_requires=">=3.6",
)
